==========
GENEPIDGIN
==========

Genepidgin is a suite of tools that assist in evaluation and assignment gene product names. There are three primary components:

``genepidgin *cleaner*``
    standardizes gene names per UNIPROT naming guidelines
``genepidgin *compare*``
    compares two or more sets of gene names
``genepidgin *select*``
    selects the most appropriate product name from a vareity of homology evidence

For more information, including current development status, please visit `genepidgin's documentation`_.

.. _genepidgin's documentation: http://genepidgin.readthedocs.org/

